@@ -1,39 +1,53 @@
+import sys
+
 try: True
 except NameError:
     True = 1
     False = 0
 
-import sys
-
-# don't edit these here: do eg.
-# import ClientCookie; ClientCookie.DEBUG_STREAM = True
-# DEBUG_STREAM is used for errors and warnings if the logging and warnings
-# modules respectively aren't present.
-DEBUG_STREAM = sys.stderr
-# These work like equivalents from logging.  Use logging direct if you
-# have 2.3.
-from _Debug import getLogger, NOTSET, INFO, DEBUG
+# If you hate the idea of turning bugs into warnings, do:
+# import ClientCookie; ClientCookie.USE_BARE_EXCEPT = False
 USE_BARE_EXCEPT = True
+WARNINGS_STREAM = sys.stdout
 
 # Import names so that they can be imported directly from the package, like
 # this:
 #from ClientCookie import <whatever>
+
+# These work like equivalents from logging.  Use logging direct if you
+# have 2.3.
+from _Debug import getLogger, StreamHandler, NOTSET, INFO, DEBUG
+
 from _ClientCookie import VERSION, __doc__, \
-     CookieJar, Cookie, \
+     Cookie, \
      CookiePolicy, DefaultCookiePolicy, \
-     lwp_cookie_str
+     CookieJar, FileCookieJar, LoadError, request_host
+from _LWPCookieJar import LWPCookieJar, lwp_cookie_str
 from _MozillaCookieJar import MozillaCookieJar
 from _MSIECookieJar import MSIECookieJar
+try:
+    import bsddb
+except ImportError:
+    pass
+else:
+    from _BSDDBCookieJar import BSDDBCookieJar, CreateBSDDBCookieJar
+#from _MSIEDBCookieJar import MSIEDBCookieJar
+#from _ConnCache import ConnectionCache
 try:
     from urllib2 import AbstractHTTPHandler
 except ImportError:
     pass
 else:
     from ClientCookie._urllib2_support import \
-         HTTPHandler, build_opener, install_opener, urlopen, \
-         HTTPRedirectHandler
+         Request, \
+         OpenerDirector, build_opener, install_opener, urlopen, \
+         OpenerFactory, urlretrieve, BaseHandler, HeadParser
+    try:
+        from ClientCookie._urllib2_support import XHTMLCompatibleHeadParser
+    except ImportError:
+        pass
     from ClientCookie._urllib2_support import \
-         Request, OpenerDirector, BaseProcessor, \
+         HTTPHandler, HTTPRedirectHandler, \
          HTTPRequestUpgradeProcessor, \
          HTTPEquivProcessor, SeekableProcessor, HTTPCookieProcessor, \
          HTTPRefererProcessor, \
@@ -53,8 +67,6 @@ else:
     if hasattr(httplib, 'HTTPS'):
         from ClientCookie._urllib2_support import HTTPSHandler
     del AbstractHTTPHandler, httplib
-from _Util import http2time
+from _Util import http2time, response_seek_wrapper
 str2time = http2time
 del http2time
-
-del sys
