@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Tests for ClientCookie._ClientCookie."""
 
 import urllib2, re, os, string, StringIO, mimetools, time
@@ -12,10 +11,6 @@ except NameError:
     True = 1
     False = 0
 
-## import logging
-## l = logging.getLogger("ClientCookie")
-## l.setLevel(logging.DEBUG)
-
 class FakeResponse:
     def __init__(self, headers=[], url=None):
         """
@@ -49,6 +44,8 @@ def _interact(cookiejar, url, set_cookie_hdrs, hdr_name):
 
 class CookieTests(TestCase):
     # XXX
+    # Get rid of string comparisons where not actually testing str / repr.
+    # .clear() etc.
     # IP addresses like 50 (single number, no dot) and domain-matching
     #  functions (and is_HDN)?  See draft RFC 2965 errata.
     # Strictness switches
@@ -92,25 +89,56 @@ class CookieTests(TestCase):
 ##   just the 7 special TLD's listed in their spec. And folks rely on
 ##   that...
 
+    def test_domain_return_ok(self):
+        # test optimization: .domain_return_ok() should filter out most
+        # domains in the CookieJar before we try to access them (because that
+        # may require disk access -- in particular, with MSIECookieJar)
+        # This is only a rough check for performance reasons, so it's not too
+        # critical as long as it's sufficiently liberal.
+        import ClientCookie
+        pol = ClientCookie.DefaultCookiePolicy()
+        for url, domain, ok in [
+            ("http://foo.bar.com/", "blah.com", False),
+            ("http://foo.bar.com/", "rhubarb.blah.com", False),
+            ("http://foo.bar.com/", "rhubarb.foo.bar.com", False),
+            ("http://foo.bar.com/", ".foo.bar.com", True),
+            ("http://foo.bar.com/", "foo.bar.com", True),
+            ("http://foo.bar.com/", ".bar.com", True),
+            ("http://foo.bar.com/", "com", True),
+            ("http://foo.com/", "rhubarb.foo.com", False),
+            ("http://foo.com/", ".foo.com", True),
+            ("http://foo.com/", "foo.com", True),
+            ("http://foo.com/", "com", True),
+            ("http://foo/", "rhubarb.foo", False),
+            ("http://foo/", ".foo", True),
+            ("http://foo/", "foo", True),
+            ("http://foo/", "foo.local", True),
+            ("http://foo/", ".local", True),
+            ]:
+            request = ClientCookie.Request(url)
+            r = pol.domain_return_ok(domain, request)
+            if ok: self.assert_(r)
+            else: self.assert_(not r)
+
     def test_missing_name(self):
         from ClientCookie import MozillaCookieJar, lwp_cookie_str
 
         # missing = sign in Cookie: header is regarded by Mozilla as a missing
-        # name, and accepted as an anonymous cookie.
+        # NAME.  WE regard it as a missing VALUE.
         filename = os.path.abspath("cookies2.txt")
         c = MozillaCookieJar(filename)
         interact_netscape(c, "http://www.acme.com/", 'eggs')
         interact_netscape(c, "http://www.acme.com/", '"spam"; path=/foo/')
-        cookie = c.cookies["www.acme.com"]["/"][None]
-        assert cookie.name is None
-        assert cookie.value == "eggs"
-        cookie = c.cookies["www.acme.com"]['/foo/'][None]
-        assert cookie.name is None
-        assert cookie.value == '"spam"'
+        cookie = c._cookies["www.acme.com"]["/"]['eggs']
+        assert cookie.name == "eggs"
+        assert cookie.value is None
+        cookie = c._cookies["www.acme.com"]['/foo/']['"spam"']
+        assert cookie.name == '"spam"'
+        assert cookie.value is None
         assert lwp_cookie_str(cookie) == (
-            r'"\"spam\""; path="/foo/"; domain="www.acme.com"; '
+            r'"spam"; path="/foo/"; domain="www.acme.com"; '
             'path_spec; discard; version=0')
-        old_str = c.as_lwp_str()
+        old_str = repr(c)
         c.save(ignore_expires=True, ignore_discard=True)
         try:
             c = MozillaCookieJar(filename)
@@ -118,10 +146,29 @@ class CookieTests(TestCase):
         finally:
             os.unlink(c.filename)
         # cookies unchanged apart from lost info re. whether path was specified
-        assert c.as_lwp_str() == re.sub("; path_spec", "", old_str)
+        assert repr(c) == \
+               re.sub("path_specified=%s" % True, "path_specified=%s" % False,
+                      old_str)
         assert interact_netscape(c, "http://www.acme.com/foo/") == \
                '"spam"; eggs'
 
+    def test_rfc2109_handling(self):
+        # 2109 cookies have rfc2109 attr set correctly, and are handled
+        # as 2965 or Netscape cookies depending on policy settings
+        from ClientCookie import CookieJar, DefaultCookiePolicy
+
+        for policy, version in [
+            (DefaultCookiePolicy(), 0),
+            (DefaultCookiePolicy(rfc2965=True), 1),
+            (DefaultCookiePolicy(rfc2109_as_netscape=True), 0),
+            (DefaultCookiePolicy(rfc2965=True, rfc2109_as_netscape=True), 0),
+            ]:
+            c = CookieJar(policy)
+            interact_netscape(c, "http://www.example.com/", "ni=ni; Version=1")
+            cookie = c._cookies["www.example.com"]["/"]["ni"]
+            self.assert_(cookie.rfc2109)
+            self.assertEqual(cookie.version, version)
+
     def test_ns_parser(self):
         from ClientCookie import CookieJar
         from ClientCookie._ClientCookie import DEFAULT_HTTP_PORT
@@ -135,30 +182,44 @@ class CookieTests(TestCase):
         interact_netscape(c, "http://www.acme.com:80/", 'spam=eggs; '
                           'expires="Foo Bar 25 33:22:11 3022"')
 
-        cookie = c.cookies[".acme.com"]["/"]["spam"]
+        cookie = c._cookies[".acme.com"]["/"]["spam"]
         assert cookie.domain == ".acme.com"
         assert cookie.domain_specified
         assert cookie.port == DEFAULT_HTTP_PORT
         assert not cookie.port_specified
         # case is preserved
-        assert cookie.rest.has_key("blArgh") and not cookie.rest.has_key("blargh")
+        assert (cookie.has_nonstandard_attr("blArgh") and
+                not cookie.has_nonstandard_attr("blargh"))
 
-        cookie = c.cookies["www.acme.com"]["/"]["ni"]
+        cookie = c._cookies["www.acme.com"]["/"]["ni"]
         assert cookie.domain == "www.acme.com"
         assert not cookie.domain_specified
         assert cookie.port == "80,8080"
         assert cookie.port_specified
 
-        cookie = c.cookies["www.acme.com"]["/"]["nini"]
+        cookie = c._cookies["www.acme.com"]["/"]["nini"]
         assert cookie.port is None
         assert not cookie.port_specified
 
         # invalid expires should not cause cookie to be dropped
-        foo = c.cookies["www.acme.com"]["/"]["foo"]
-        spam = c.cookies["www.acme.com"]["/"]["foo"]
+        foo = c._cookies["www.acme.com"]["/"]["foo"]
+        spam = c._cookies["www.acme.com"]["/"]["foo"]
         assert foo.expires is None
         assert spam.expires is None
 
+    def test_ns_parser_special_names(self):
+        # names such as 'expires' are not special in first name=value pair
+        # of Set-Cookie: header
+        from ClientCookie import CookieJar
+
+        c = CookieJar()
+        interact_netscape(c, "http://www.acme.com/", 'expires=eggs')
+        interact_netscape(c, "http://www.acme.com/", 'version=eggs; spam=eggs')
+
+        cookies = c._cookies["www.acme.com"]["/"]
+        self.assert_(cookies.has_key('expires'))
+        self.assert_(cookies.has_key('version'))
+
     def test_expires(self):
         from ClientCookie._Util import time2netscape
         from ClientCookie import CookieJar
@@ -201,45 +262,46 @@ class CookieTests(TestCase):
         # XXX RFC 2965 expiry rules (some apply to V0 too)
 
     def test_default_path(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
         # RFC 2965
+        pol = DefaultCookiePolicy(rfc2965=True)
 
-        c = CookieJar()
+        c = CookieJar(pol)
         interact_2965(c, "http://www.acme.com/", 'spam="bar"; Version="1"')
-        assert c.cookies["www.acme.com"].has_key("/")
+        assert c._cookies["www.acme.com"].has_key("/")
 
-        c = CookieJar()
+        c = CookieJar(pol)
         interact_2965(c, "http://www.acme.com/blah", 'eggs="bar"; Version="1"')
-        assert c.cookies["www.acme.com"].has_key("/")
+        assert c._cookies["www.acme.com"].has_key("/")
   
-        c = CookieJar()
+        c = CookieJar(pol)
         interact_2965(c, "http://www.acme.com/blah/rhubarb",
                       'eggs="bar"; Version="1"')
-        assert c.cookies["www.acme.com"].has_key("/blah/")
+        assert c._cookies["www.acme.com"].has_key("/blah/")
 
-        c = CookieJar()
+        c = CookieJar(pol)
         interact_2965(c, "http://www.acme.com/blah/rhubarb/",
                       'eggs="bar"; Version="1"')
-        assert c.cookies["www.acme.com"].has_key("/blah/rhubarb/")
+        assert c._cookies["www.acme.com"].has_key("/blah/rhubarb/")
 
         # Netscape
 
         c = CookieJar()
         interact_netscape(c, "http://www.acme.com/", 'spam="bar"')
-        assert c.cookies["www.acme.com"].has_key("/")
+        assert c._cookies["www.acme.com"].has_key("/")
 
         c = CookieJar()
         interact_netscape(c, "http://www.acme.com/blah", 'eggs="bar"')
-        assert c.cookies["www.acme.com"].has_key("/")
+        assert c._cookies["www.acme.com"].has_key("/")
   
         c = CookieJar()
         interact_netscape(c, "http://www.acme.com/blah/rhubarb", 'eggs="bar"')
-        assert c.cookies["www.acme.com"].has_key("/blah")
+        assert c._cookies["www.acme.com"].has_key("/blah")
 
         c = CookieJar()
         interact_netscape(c, "http://www.acme.com/blah/rhubarb/", 'eggs="bar"')
-        assert c.cookies["www.acme.com"].has_key("/blah/rhubarb")
+        assert c._cookies["www.acme.com"].has_key("/blah/rhubarb")
 
     def test_escape_path(self):
         from ClientCookie._ClientCookie import escape_path
@@ -260,16 +322,15 @@ class CookieTests(TestCase):
             ("/foo\031/bar", "/foo%19/bar"),
             ("/\175foo/bar", "/%7Dfoo/bar"),
             ]
-# XXXX causes SyntaxError with 1.5.2
-##         try:
-##             unicode
-##         except NameError:
-##             pass
-##         else:
-##             cases.append(
-##             # unicode
-##             (u"/foo/bar\uabcd", "/foo/bar%EA%AF%8D")  # UTF-8 encoded
-##             )
+        try:
+            unicode
+        except NameError:
+            pass
+        else:
+            cases.append(
+            # unicode
+            (u"/foo/bar\uabcd", "/foo/bar%EA%AF%8D")  # UTF-8 encoded
+            )
         for arg, result in cases:
             self.assert_(escape_path(arg) == result)
 
@@ -291,7 +352,7 @@ class CookieTests(TestCase):
         self.assert_(request_path(req) == "/")
 
     def test_request_port(self):
-        from ClientCookie import Request
+        from urllib2 import Request
         from ClientCookie._ClientCookie import request_port, DEFAULT_HTTP_PORT
         req = Request("http://www.acme.com:1234/",
                       headers={"Host": "www.acme.com:4321"})
@@ -394,6 +455,24 @@ class CookieTests(TestCase):
         interact_2965(c, "http://www.nasty.com/", 'foo=bar; domain=friendly.org; Version="1"')
         assert len(c) == 0
 
+    def test_strict_domain(self):
+        # Cookies whose domain is a country-code tld like .co.uk should
+        # not be set if CookiePolicy.strict_domain is true.
+        from ClientCookie import CookieJar, DefaultCookiePolicy
+
+        cp = DefaultCookiePolicy(strict_domain=True)
+        cj = CookieJar(policy=cp)
+        interact_netscape(cj, "http://example.co.uk/", 'no=problemo')
+        interact_netscape(cj, "http://example.co.uk/",
+                          'okey=dokey; Domain=.example.co.uk')
+        self.assertEquals(len(cj), 2)
+        for pseudo_tld in [".co.uk", ".org.za", ".tx.us"]:
+            interact_netscape(cj, "http://example.%s/" % pseudo_tld,
+                              'spam=eggs; Domain=.co.uk')
+            self.assertEquals(len(cj), 2)
+        # XXXX what about blah.tv, .name, etc etc?  See Konqueror
+        # (kcookiejar.cpp) and Mozilla implementations.
+
     def test_two_component_domain_ns(self):
         # Netscape: .www.bar.com, www.bar.com, .bar.com, bar.com, no domain should
         #  all get accepted, as should .acme.com, acme.com and no domain for
@@ -405,12 +484,14 @@ class CookieTests(TestCase):
         # two-component V0 domain is OK
         interact_netscape(c, "http://foo.net/", 'ns=bar')
         assert len(c) == 1
-        assert c.cookies["foo.net"]["/"]["ns"].value == "bar"
+        assert c._cookies["foo.net"]["/"]["ns"].value == "bar"
         assert interact_netscape(c, "http://foo.net/") == "ns=bar"
         # *will* be returned to any other domain (unlike RFC 2965)...
         assert interact_netscape(c, "http://www.foo.net/") == "ns=bar"
         # ...unless requested otherwise
-        c.policy.strict_ns_domain = DefaultCookiePolicy.DomainStrictNonDomain
+        pol = DefaultCookiePolicy(
+            strict_ns_domain=DefaultCookiePolicy.DomainStrictNonDomain)
+        c.set_policy(pol)
         assert interact_netscape(c, "http://www.foo.net/") == ""
 
         # unlike RFC 2965, even explicit two-component domain is OK,
@@ -421,8 +502,8 @@ class CookieTests(TestCase):
         interact_netscape(c, "http://foo.net/foo/bar/",
                           'spam2=eggs; domain=.foo.net')
         assert len(c) == 3
-        assert c.cookies[".foo.net"]["/foo"]["spam1"].value == "eggs"
-        assert c.cookies[".foo.net"]["/foo/bar"]["spam2"].value == "eggs"
+        assert c._cookies[".foo.net"]["/foo"]["spam1"].value == "eggs"
+        assert c._cookies[".foo.net"]["/foo/bar"]["spam2"].value == "eggs"
         assert interact_netscape(c, "http://foo.net/foo/bar/") == \
                "spam2=eggs; spam1=eggs; ns=bar"
 
@@ -440,14 +521,15 @@ class CookieTests(TestCase):
         assert len(c) == 4
 
     def test_two_component_domain_rfc2965(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        pol = DefaultCookiePolicy(rfc2965=True)
+        c = CookieJar(pol)
 
         # two-component V1 domain is OK
         interact_2965(c, "http://foo.net/", 'foo=bar; Version="1"')
         assert len(c) == 1
-        assert c.cookies["foo.net"]["/"]["foo"].value == "bar"
+        assert c._cookies["foo.net"]["/"]["foo"].value == "bar"
         assert interact_2965(c, "http://foo.net/") == "$Version=1; foo=bar"
         # won't be returned to any other domain (because domain was implied)
         assert interact_2965(c, "http://www.foo.net/") == ""
@@ -464,7 +546,7 @@ class CookieTests(TestCase):
         # set, because .foo.net domain-matches .foo.net
         interact_2965(c, "http://www.foo.net/foo/",
                       'spam=eggs; domain=foo.net; Version="1"')
-        assert c.cookies[".foo.net"]["/foo/"]["spam"].value == "eggs"
+        assert c._cookies[".foo.net"]["/foo/"]["spam"].value == "eggs"
         assert len(c) == 2
         assert interact_2965(c, "http://foo.net/foo/") == "$Version=1; foo=bar"
         assert interact_2965(c, "http://www.foo.net/foo/") == \
@@ -481,7 +563,8 @@ class CookieTests(TestCase):
         assert len(c) == 3
 
     def test_domain_allow(self):
-        from ClientCookie import CookieJar, DefaultCookiePolicy, Request
+        from ClientCookie import CookieJar, DefaultCookiePolicy
+        from ClientCookie import Request
 
         c = CookieJar(policy=DefaultCookiePolicy(
             blocked_domains=["acme.com"],
@@ -514,10 +597,14 @@ class CookieTests(TestCase):
         assert not req.has_header("Cookie")
 
     def test_domain_block(self):
-        from ClientCookie import CookieJar, DefaultCookiePolicy, Request
+        from ClientCookie import CookieJar, DefaultCookiePolicy
+        from ClientCookie import Request
 
-        c = CookieJar(policy=DefaultCookiePolicy(
-            blocked_domains=[".acme.com"]))
+        #import logging; logging.getLogger("ClientCookie").setLevel(logging.DEBUG)
+
+        pol = DefaultCookiePolicy(
+            rfc2965=True, blocked_domains=[".acme.com"])
+        c = CookieJar(policy=pol)
         headers = ["Set-Cookie: CUSTOMER=WILE_E_COYOTE; path=/"]
 
         req = Request("http://www.acme.com/")
@@ -525,7 +612,7 @@ class CookieTests(TestCase):
         c.extract_cookies(res, req)
         assert len(c) == 0
 
-        c.policy.set_blocked_domains(["acme.com"])
+        pol.set_blocked_domains(["acme.com"])
         c.extract_cookies(res, req)
         assert len(c) == 1
 
@@ -540,7 +627,7 @@ class CookieTests(TestCase):
                 req.has_header("Cookie2"))
 
         c.clear()
-        c.policy.set_blocked_domains([".acme.com"])
+        pol.set_blocked_domains([".acme.com"])
         c.extract_cookies(res, req)
         assert len(c) == 1
 
@@ -561,33 +648,34 @@ class CookieTests(TestCase):
             for whitespace in " ", "":
                 c = CookieJar()
                 if ns:
-                    c.policy.rfc2965 = False
+                    pol = DefaultCookiePolicy(rfc2965=False)
                     int = interact_netscape
                     vs = ""
                 else:
-                    c.policy.rfc2965 = True
+                    pol = DefaultCookiePolicy(rfc2965=True)
                     int = interact_2965
                     vs = "; Version=1"
+                c.set_policy(pol)
                 url = "http://www.acme.com/"
                 int(c, url, "foo1=bar%s%s" % (vs, whitespace))
                 int(c, url, "foo2=bar%s; secure%s" %  (vs, whitespace))
-                assert not c.cookies["www.acme.com"]["/"]["foo1"].secure, \
+                assert not c._cookies["www.acme.com"]["/"]["foo1"].secure, \
                        "non-secure cookie registered secure"
-                assert c.cookies["www.acme.com"]["/"]["foo2"].secure, \
+                assert c._cookies["www.acme.com"]["/"]["foo2"].secure, \
                        "secure cookie registered non-secure"
 
     def test_quote_cookie_value(self):
-        from ClientCookie import CookieJar
-        c = CookieJar()
+        from ClientCookie import CookieJar, DefaultCookiePolicy
+        c = CookieJar(policy=DefaultCookiePolicy(rfc2965=True))
         interact_2965(c, "http://www.acme.com/", r'foo=\b"a"r; Version=1')
         h = interact_2965(c, "http://www.acme.com/")
         assert h == r'$Version=1; foo=\\b\"a\"r'
 
     def test_missing_final_slash(self):
         # Missing slash from request URL's abs_path should be assumed present.
-        from ClientCookie import CookieJar, Request
+        from ClientCookie import CookieJar, Request, DefaultCookiePolicy
         url = "http://www.acme.com"
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965=True))
         interact_2965(c, url, "foo=bar; Version=1")
         req = Request(url)
         assert len(c) == 1
@@ -595,23 +683,25 @@ class CookieTests(TestCase):
         assert req.has_header("Cookie")
 
     def test_domain_mirror(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        pol = DefaultCookiePolicy(rfc2965=True)
+
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, "spam=eggs; Version=1")
         h = interact_2965(c, url)
-        assert string.find("Domain", h) == -1, \
+        assert string.find(h, "Domain") == -1, \
                "absent domain returned with domain present"
 
-        c = CookieJar()
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, 'spam=eggs; Version=1; Domain=.bar.com')
         h = interact_2965(c, url)
         assert string.find(h, '$Domain=".bar.com"') != -1, \
                "domain not returned"
 
-        c = CookieJar()
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         # note missing initial dot in Domain
         interact_2965(c, url, 'spam=eggs; Version=1; Domain=bar.com')
@@ -620,46 +710,50 @@ class CookieTests(TestCase):
                "domain not returned"
 
     def test_path_mirror(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        pol = DefaultCookiePolicy(rfc2965=True)
+
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, "spam=eggs; Version=1")
         h = interact_2965(c, url)
-        assert string.find("Path", h) == -1, \
+        assert string.find(h, "Path") == -1, \
                "absent path returned with path present"
 
-        c = CookieJar()
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, 'spam=eggs; Version=1; Path=/')
         h = interact_2965(c, url)
         assert string.find(h, '$Path="/"') != -1, "path not returned"
 
     def test_port_mirror(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        pol = DefaultCookiePolicy(rfc2965=True)
+
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, "spam=eggs; Version=1")
         h = interact_2965(c, url)
-        assert string.find("Port", h) == -1, \
+        assert string.find(h, "Port") == -1, \
                "absent port returned with port present"
 
-        c = CookieJar()
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, "spam=eggs; Version=1; Port")
         h = interact_2965(c, url)
         assert re.search("\$Port([^=]|$)", h), \
                "port with no value not returned with no value"
 
-        c = CookieJar()
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, 'spam=eggs; Version=1; Port="80"')
         h = interact_2965(c, url)
         assert string.find(h, '$Port="80"') != -1, \
                "port with single value not returned with single value"
 
-        c = CookieJar()
+        c = CookieJar(pol)
         url = "http://foo.bar.com/"
         interact_2965(c, url, 'spam=eggs; Version=1; Port="80,8080"')
         h = interact_2965(c, url)
@@ -667,15 +761,15 @@ class CookieTests(TestCase):
                "port with multiple values not returned with multiple values"
 
     def test_no_return_comment(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965=True))
         url = "http://foo.bar.com/"
         interact_2965(c, url, 'spam=eggs; Version=1; '
                       'Comment="does anybody read these?"; '
                       'CommentURL="http://foo.bar.net/comment.html"')
         h = interact_2965(c, url)
-        assert string.find("Comment", h) == -1, \
+        assert string.find(h, "Comment") == -1, \
                "Comment or CommentURL cookie-attributes returned to server"
 
 # just pondering security here -- this isn't really a test (yet)
@@ -693,9 +787,9 @@ class CookieTests(TestCase):
 ##         print h
 
     def test_Cookie_iterator(self):
-        from ClientCookie import CookieJar, Cookie
+        from ClientCookie import CookieJar, Cookie, DefaultCookiePolicy
 
-        cs = CookieJar()
+        cs = CookieJar(DefaultCookiePolicy(rfc2965=True))
         # add some random cookies
         interact_2965(cs, "http://blah.spam.org/", 'foo=eggs; Version=1; '
                       'Comment="does anybody read these?"; '
@@ -708,14 +802,14 @@ class CookieTests(TestCase):
                       r'port="90,100, 80,8080"; '
                       r'max-age=100; Comment = "Just kidding! (\"|\\\\) "')
 
-        versions = [1, 1, 1, 0, 1, 1]
+        versions = [1, 1, 1, 0, 1]
         names = ["bang", "foo", "foo", "spam", "foo"]
         domains = [".sol.no", "blah.spam.org", "www.acme.com",
                    "www.acme.com", "www.acme.com"]
-        paths = ["/", "/", "/", "/blah", "/blah/", "/"]
+        paths = ["/", "/", "/", "/blah", "/blah/"]
 
         # sequential iteration
-        for i in range(3):
+        for i in range(4):
             i = 0
             for c in cs:
                 assert isinstance(c, Cookie)
@@ -750,7 +844,7 @@ class CookieTests(TestCase):
             ["foo=bar; expires=Foo Bar 12 33:22:11 2000"]) == \
             [[("foo", "bar"), ("expires", None), ("version", "0")]]
         # missing cookie name (valid cookie)
-        assert parse_ns_headers(["foo"]) == [[(None, "foo"), ("version", "0")]]
+        assert parse_ns_headers(["foo"]) == [[("foo", None), ("version", "0")]]
         # shouldn't add version if header is empty
         assert parse_ns_headers([""]) == []
 
@@ -780,7 +874,7 @@ class CookieTests(TestCase):
         # cookie with invalid expires is treated as session cookie
         headers = ["Set-Cookie: c=foo; expires=Foo Bar 12 33:22:11 2000"]
         c = cookiejar_from_cookie_headers(headers)
-        cookie = c.cookies["www.example.com"]["/"]["c"]
+        cookie = c._cookies["www.example.com"]["/"]["c"]
         assert cookie.expires is None
 
 
@@ -788,7 +882,7 @@ class LWPCookieTests(TestCase):
     # Tests taken from libwww-perl, with a few modifications.
 
     def test_netscape_example_1(self):
-        from ClientCookie import CookieJar, Request
+        from ClientCookie import CookieJar, Request, DefaultCookiePolicy
 
         #-------------------------------------------------------------------
         # First we check that it works for the original example at
@@ -830,7 +924,7 @@ class LWPCookieTests(TestCase):
 
         headers = []
 
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965 = True))
 
         #req = Request("http://1.1.1.1/",
         #              headers={"Host": "www.acme.com:80"})
@@ -935,13 +1029,13 @@ class LWPCookieTests(TestCase):
                          req.get_header("Cookie"))
 
     def test_ietf_example_1(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
         #-------------------------------------------------------------------
         # Then we test with the examples from draft-ietf-http-state-man-mec-03.txt
         #
         # 5.  EXAMPLES
 
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965=True))
 
         # 
         # 5.1  Example 1
@@ -1049,7 +1143,7 @@ class LWPCookieTests(TestCase):
         # contains all the cookies received so far.
 
     def test_ietf_example_2(self):
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
         # 5.2  Example 2
         # 
@@ -1057,7 +1151,7 @@ class LWPCookieTests(TestCase):
         # of request and response headers has been omitted.  Assume the user agent
         # has no stored cookies.
 
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965=True))
 
         # Imagine the user agent has received, in response to earlier requests,
         # the response headers
@@ -1105,9 +1199,11 @@ class LWPCookieTests(TestCase):
 
     def test_rejection(self):
         # Test rejection of Set-Cookie2 responses based on domain, path, port.
-        from ClientCookie import CookieJar
+        from ClientCookie import LWPCookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        pol = DefaultCookiePolicy(rfc2965=True)
+
+        c = LWPCookieJar(policy=pol)
 
         max_age = "max-age=3600"
 
@@ -1186,7 +1282,7 @@ class LWPCookieTests(TestCase):
             c.save(filename, ignore_discard=True)
             old = repr(c)
 
-            c = CookieJar()
+            c = LWPCookieJar(policy=pol)
             c.load(filename, ignore_discard=True)
         finally:
             try: os.unlink(filename)
@@ -1197,42 +1293,37 @@ class LWPCookieTests(TestCase):
     def test_url_encoding(self):
         # Try some URL encodings of the PATHs.
         # (the behaviour here has changed from libwww-perl)
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
-##         interact_2965(c, "http://www.acme.com/foo%2f%25/%40%40%0Anew%E5/%E5",
-##                  "foo  =   bar; version    =   1")
+        c = CookieJar(DefaultCookiePolicy(rfc2965=True))
 
-##         cookie = interact_2965(c, "http://www.acme.com/foo%2f%25/@@%0anew/",
-##                           'bar=baz; path="/foo/"; version=1');
         interact_2965(c, "http://www.acme.com/foo%2f%25/%3c%3c%0Anew%E5/%E5",
                       "foo  =   bar; version    =   1")
 
         cookie = interact_2965(
-            c, "http://www.acme.com/foo%2f%25/<<%0anew/",
+            c, "http://www.acme.com/foo%2f%25/<<%0anew\345/\346\370\345",
             'bar=baz; path="/foo/"; version=1');
         version_re = re.compile(r'^\$version=\"?1\"?', re.I)
         assert (string.find(cookie, "foo=bar") != -1 and
                 version_re.search(cookie))
 
-##         cookie = interact_2965(c, "http://www.acme.com/foo/%25/@@%0anew/")
         cookie = interact_2965(
-            c, "http://www.acme.com/foo/%25/<<%0anew/")
+            c, "http://www.acme.com/foo/%25/<<%0anew\345/\346\370\345")
         assert not cookie
 
         # unicode URL doesn't raise exception, as it used to!
-        # XXXX 1.5.2 SyntaxError
-        #cookie = interact_2965(c, u"http://www.acme.com/\xfc")
+        cookie = interact_2965(c, u"http://www.acme.com/\xfc")
 
     def test_mozilla(self):
         # Save / load Mozilla/Netscape cookie file format.
-        from ClientCookie import MozillaCookieJar
+        from ClientCookie import MozillaCookieJar, DefaultCookiePolicy
 
         year_plus_one = localtime(time.time())[0] + 1
 
         filename = "cookies.txt"
 
-        c = MozillaCookieJar(filename)
+        c = MozillaCookieJar(filename,
+                             policy=DefaultCookiePolicy(rfc2965=True))
         interact_2965(c, "http://www.acme.com/",
                       "foo1=bar; max-age=100; Version=1")
         interact_2965(c, "http://www.acme.com/",
@@ -1248,10 +1339,11 @@ class LWPCookieTests(TestCase):
                           "fooc=bar; Domain=www.foo.com; %s" % expires)
 
         def save_and_restore(cj, ignore_discard, filename=filename):
-            from ClientCookie import MozillaCookieJar
+            from ClientCookie import MozillaCookieJar, DefaultCookiePolicy
             try:
                 cj.save(ignore_discard=ignore_discard)
-                new_c = MozillaCookieJar(filename)
+                new_c = MozillaCookieJar(filename,
+                                         DefaultCookiePolicy(rfc2965=True))
                 new_c.load(ignore_discard=ignore_discard)
             finally:
                 try: os.unlink(filename)
@@ -1260,11 +1352,11 @@ class LWPCookieTests(TestCase):
 
         new_c = save_and_restore(c, True)
         assert len(new_c) == 6  # none discarded
-        assert string.find(new_c.as_lwp_str(), "foo1=bar") != -1
+        assert string.find(repr(new_c), "name='foo1', value='bar'") != -1
 
         new_c = save_and_restore(c, False)
         assert len(new_c) == 4  # 2 of them discarded on save
-        assert string.find(new_c.as_lwp_str(), "foo1=bar") != -1
+        assert string.find(repr(new_c), "name='foo1', value='bar'") != -1
 
     def test_netscape_misc(self):
         # Some additional Netscape cookies tests.
@@ -1290,25 +1382,39 @@ class LWPCookieTests(TestCase):
         c.add_cookie_header(req)
         assert (
             string.find(req.get_header("Cookie"), "PART_NUMBER=3,4") != -1 and
-            string.find(req.get_header("Cookie"), "Customer=WILE_E_COYOTE") != -1)
+            string.find(
+            req.get_header("Cookie"), "Customer=WILE_E_COYOTE") != -1)
 
-    def test_intranet_domains(self):
+    def test_intranet_domains_2965(self):
         # Test handling of local intranet hostnames without a dot.
-        from ClientCookie import CookieJar
+        from ClientCookie import CookieJar, DefaultCookiePolicy
 
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965=True))
         interact_2965(c, "http://example/",
                       "foo1=bar; PORT; Discard; Version=1;")
         cookie = interact_2965(c, "http://example/",
                                'foo2=bar; domain=".local"; Version=1')
-        assert not (string.find(cookie, "foo1=bar") == -1)
+        assert string.find(cookie, "foo1=bar") >= 0
 
         interact_2965(c, "http://example/", 'foo3=bar; Version=1')
         cookie = interact_2965(c, "http://example/")
-        assert not (string.find(cookie, "foo2=bar") == -1 or len(c) != 3)
+        assert string.find(cookie, "foo2=bar") >= 0 and len(c) == 3
+
+    def test_intranet_domains_ns(self):
+        from ClientCookie import CookieJar, DefaultCookiePolicy
+
+        c = CookieJar(DefaultCookiePolicy(rfc2965 = False))
+        interact_netscape(c, "http://example/", "foo1=bar")
+        cookie = interact_netscape(c, "http://example/",
+                                   'foo2=bar; domain=.local')
+        assert len(c) == 2
+        assert string.find(cookie, "foo1=bar") >= 0
+
+        cookie = interact_netscape(c, "http://example/")
+        assert string.find(cookie, "foo2=bar") >= 0 and len(c) == 2
 
     def test_empty_path(self):
-        from ClientCookie import CookieJar, Request
+        from ClientCookie import CookieJar, Request, DefaultCookiePolicy
 
         # Test for empty path
         # Broken web-server ORION/1.3.38 returns to the client response like
@@ -1317,7 +1423,7 @@ class LWPCookieTests(TestCase):
         #
         # ie. with Path set to nothing.
         # In this case, extract_cookies() must set cookie to / (root)
-        c = CookieJar()
+        c = CookieJar(DefaultCookiePolicy(rfc2965 = True))
         headers = []
 
         req = Request("http://www.ants.com/")
@@ -1361,7 +1467,7 @@ class LWPCookieTests(TestCase):
 ##         # X-Meta-Description: Trip.com privacy policy
 ##         # X-Meta-Keywords: privacy policy
 
-##         req = Request(
+##         req = urllib2.Request(
 ##             'http://www.trip.com/trs/trip/flighttracker/flight_tracker_home.xsl')
 ##         headers = []
 ##         headers.append("Set-Cookie: trip.appServer=1111-0000-x-024;Domain=.trip.com;Path=/")
