@@ -2,6 +2,32 @@
 
 from unittest import TestCase
 
+try: True
+except NameError:
+    True = 1
+    False = 0
+
+class IsHtmlTests(TestCase):
+    def test_is_html(self):
+        from ClientCookie._HeadersUtil import is_html
+        for allow_xhtml in False, True:
+            for cths, ext, expect in [
+                (["text/html"], ".html", True),
+                (["text/html", "text/plain"], ".html", True),
+                # Content-type takes priority over file extension from URL
+                (["text/html"], ".txt", True),
+                (["text/plain"], ".html", False),
+                # use extension if no Content-Type
+                ([], ".html", True),
+                ([], ".gif", False),
+                # don't regard XHTML as HTML (unless user explicitly asks for it),
+                # since we don't yet handle XML properly
+                ([], ".xhtml", allow_xhtml),
+                (["text/xhtml"], ".xhtml", allow_xhtml),
+                ]:
+                url = "http://example.com/foo"+ext
+                self.assertEqual(expect, is_html(cths, url, allow_xhtml))
+
 class HeaderTests(TestCase):
     def test_parse_ns_headers(self):
         from ClientCookie._HeadersUtil import parse_ns_headers
