@@ -370,12 +370,15 @@ class HandlerTests(unittest.TestCase):
             TESTFN = "test.txt"
             urlpath = sanepathname2url(os.path.abspath(TESTFN))
             towrite = "hello, world\n"
+            try:
+                fqdn = socket.gethostbyname(socket.gethostname())
+            except socket.gaierror:
+                fqdn = "localhost"
             for url in [
                 "file://localhost%s" % urlpath,
                 "file://%s" % urlpath,
                 "file://%s%s" % (socket.gethostbyname('localhost'), urlpath),
-                "file://%s%s" % (socket.gethostbyname(socket.gethostname()),
-                                 urlpath),
+                "file://%s%s" % (fqdn, urlpath)
                 ]:
                 f = open(TESTFN, "wb")
                 try:
@@ -664,7 +667,11 @@ class HandlerTests(unittest.TestCase):
         o = h.parent = MockOpener()
 
         req = urllib2.Request("http://example.com/")
-        class MockUnseekableResponse: pass
+        class MockUnseekableResponse:
+            code = 200
+            msg = "OK"
+            def info(self): pass
+            def geturl(self): return ""
         r = MockUnseekableResponse()
         newr = h.http_response(req, r)
         self.assert_(not hasattr(r, "seek"))
@@ -675,13 +682,16 @@ class HandlerTests(unittest.TestCase):
         o = h.parent = MockOpener()
 
         req = Request("http://example.com/")
-        r = MockResponse(200, "OK", MockHeaders({"Foo": "Bar", "Content-type": "text/html"}),
-                         '<html><head>'
-                         '<meta http-equiv="Refresh" content="spam">'
-                         '</head></html>')
+        r = MockResponse(
+            200, "OK",
+            MockHeaders({"Foo": "Bar", "Content-type": "text/html"}),
+            '<html><head>'
+            '<meta http-equiv="Refresh" content="spam&amp;eggs">'
+            '</head></html>'
+            )
         newr = h.http_response(req, r)
         headers = newr.info()
-        self.assert_(headers["Refresh"] == "spam")
+        self.assert_(headers["Refresh"] == "spam&eggs")
         self.assert_(headers["Foo"] == "Bar")
 
     def test_refresh(self):
@@ -757,6 +767,49 @@ class HandlerTests(unittest.TestCase):
             self.assert_(count == HTTPRedirectHandler.max_redirections)
 
 
+class UnescapeTests(unittest.TestCase):
+
+    def test_unescape_charref(self):
+        from ClientCookie._urllib2_support import \
+             unescape_charref, get_entitydefs
+        mdash_utf8 = u"\u2014".encode("utf-8")
+        for ref, codepoint, utf8, latin1 in [
+            ("38", 38, u"&".encode("utf-8"), "&"),
+            ("x2014", 0x2014, mdash_utf8, "&#x2014;"),
+            ("8212", 8212, mdash_utf8, "&#8212;"),
+            ]:
+            self.assertEqual(unescape_charref(ref, None), unichr(codepoint))
+            self.assertEqual(unescape_charref(ref, 'latin-1'), latin1)
+            self.assertEqual(unescape_charref(ref, 'utf-8'), utf8)
+
+    def test_get_entitydefs(self):
+        from ClientCookie._urllib2_support import get_entitydefs
+        ed = get_entitydefs()
+        for name, codepoint in [
+            ("amp", ord(u"&")),
+            ("lt", ord(u"<")),
+            ("gt", ord(u">")),
+            ("mdash", 0x2014),
+            ("spades", 0x2660),
+            ]:
+            self.assertEqual(ed[name], codepoint)
+
+    def test_unescape(self):
+        import htmlentitydefs
+        from ClientCookie._urllib2_support import unescape, get_entitydefs
+        data = "&amp; &lt; &mdash; &#8212; &#x2014;"
+        mdash_utf8 = u"\u2014".encode("utf-8")
+        ue = unescape(data, get_entitydefs(), "utf-8")
+        self.assertEqual("& < %s %s %s" % ((mdash_utf8,)*3), ue)
+
+        for text, expect in [
+            ("&a&amp;", "&a&"),
+            ("a&amp;", "a&"),
+            ]:
+            got = unescape(text, get_entitydefs(), "latin-1")
+            self.assertEqual(got, expect)
+
+
 class HeadParserTests(unittest.TestCase):
 
     def test(self):
